-- Vinny Loader window handler
-- coding: utf-8
import "Turbine.UI.Lotro"
import "Vinny.Common"
import "Vinny.Common.ToolTip"

local backColor = Turbine.UI.Color( 1, 1, 1 )
local Small = VL_Opt and VL_Opt.small
local isize = Small and 16 or 32
local Ssize = isize-2
VP = {
	{f="CampSite", i="CampFire", o="/csx"},
	{f="CookingRef", i="Cook", o="/crx"},
	{f="CraftMats", i="Craft", o="/cmx"},
	{f="DailyTasks", i="Ring", o="/dtx"},
	{f="EventTimer", i="Clock", o="/et"},
	{f="LostLore", i="Book", o="/llx"},
	{f="RepRef", i="Barter", o="/rrx"},
	{f="RuneUse", i="Rune", o="/rux"},
	{f="TravelRef", i="Stable", o="/trx"},
	{f="WarbandRef", i="Warband", o="/wbx"},
}
AP = Turbine.PluginManager.GetAvailablePlugins()

function pFind(pt,name)
	for i,t in pairs(pt) do
		if t.Name==name then return t end
	end
end

local np,ni = 0,0
for i,vp in ipairs(VP) do
	if pFind(AP,vp.f) then np = np+1
	else vp.i = nil end
end
if np==0 then print("Warning: No Vinny plugins found!") end

VL_Window = class( Turbine.UI.Window )

function VL_Window:Constructor()
	Turbine.UI.Window.Constructor( self )

	-- Position the window at the bottom left of the screen.
	self:SetSize( np*(isize+1)-1,isize )
	local y = Turbine.UI.Display.GetHeight()-isize
	self:SetPosition(0,y)
	self:SetBackColor( backColor )
	self:SetOpacity( .75 )
	self:SetZOrder(11000) -- Always on top
	self:SetVisible(true)

	-- load plugin icons
	for i,vp in ipairs(VP) do
		if vp.i then
			local field = "icon"..i
			local icon = Turbine.UI.Button()
			self[field] = icon
			icon.vp = vp
			icon:SetSize( isize,isize )
			icon:SetParent(self)
			icon:SetPosition( ni*(isize+1), 0)
			local path = "Vinny/"..vp.f.."/"..vp.i..".tga"
			if Small then path = "Vinny/VinnyLoader/Small/"..vp.i..".tga" end
			icon:SetBackground(path)
 			local name = vp.f
			icon.Click = function( sender,args )
				local reload = sender:IsAltKeyDown()
				local loaded = pFind(Turbine.PluginManager.GetLoadedPlugins(),name)
				if reload and loaded then
					print("Reloading "..name.." ...")
					Turbine.PluginManager.UnloadScriptState(name)
					loaded = false
				else print("Calling "..name.." ...") end
				if loaded then
					local pt = Plugins[name]
					if pt and pt.Open then pt.Open()
					else printe(name.." is already loaded.") end
				else 
					Turbine.PluginManager.LoadPlugin(name) 
				end
			end
			Vinny.Common.ToolTip(icon,2,-20,name)
			ni = ni+1
		end
	end

	function VL_Window:Add(t)
		VL_window:SetSize( (ni+1)*(isize+1)-1,isize )
		local field = "icon"..ni
		local icon = Turbine.UI.Button()
		VL_window[field] = icon
		icon.vp = vp
		icon:SetSize( isize,isize )
		icon:SetParent(VL_window)
		icon:SetPosition( ni*(isize+1), 0)
		icon:SetBackground(t.Image)
		local name = t.Name
		icon.Click = function( sender,args )
			if pFind(Turbine.PluginManager.GetLoadedPlugins(),name) then
				printe(name.." is already loaded.")
			else Turbine.PluginManager.LoadPlugin(name) end
		end
		Vinny.Common.ToolTip(icon,2,-20,name)
		print("Added "..name)
		ni = ni+1
	end

    -- Setup window dragging
    self.MouseDown = function(sender, args)
		sender.Start = args
    end

    self.MouseMove = function(sender, args)
        if sender.Start then
            sender:SetPosition(sender:GetLeft() + args.X-sender.Start.X,
								sender:GetTop() + args.Y-sender.Start.Y)
        end
    end

    self.MouseUp = function(sender, args)
        sender.Start = nil
    end

end
